# AutoTrader Indicators Library


AutoTrader features a rich [custom indicator library](indicator-library), with novel indicators to help
you gain an edge. The chart below showcases the Halftrend indicator, ported from the 
[indicator by *everget*](https://www.tradingview.com/script/U1SJ8ubc-HalfTrend/) on TradingView.


<iframe data-src="../_static/charts/halftrend.html" id="iframe" loading="lazy" style="width:100%; margin-top:1em; height:420px; overflow:hidden;" data-ga-on="wheel" data-ga-event-category="iframe" data-ga-event-action="wheel" src="../_static/charts/halftrend.html"></iframe>



